==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/OSVersionConstraintDynamicVersionRequirement.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Contains the necessary properties for a dynamic Windows version requirement
 */
@ApiModel(description = "Contains the necessary properties for a dynamic Windows version requirement")
@JsonPropertyOrder({ OSVersionConstraintDynamicVersionRequirement.JSON_PROPERTY_TYPE,
        OSVersionConstraintDynamicVersionRequirement.JSON_PROPERTY_DISTANCE_FROM_LATEST_MAJOR,
        OSVersionConstraintDynamicVersionRequirement.JSON_PROPERTY_LATEST_SECURITY_PATCH })
@JsonTypeName("OSVersionConstraint_dynamicVersionRequirement")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class OSVersionConstraintDynamicVersionRequirement implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * Indicates the type of the dynamic Windows version requirement
     */
    public enum TypeEnum {
        MINIMUM("MINIMUM"),

        EXACT("EXACT"),

        EXACT_ANY_SUPPORTED("EXACT_ANY_SUPPORTED"),

        NOT_ALLOWED("NOT_ALLOWED"),

        UNKNOWN_DEFAULT_OPEN_API("unknown_default_open_api");

        private String value;

        TypeEnum(String value) {
            this.value = value;
        }

        @JsonValue
        public String getValue() {
            return value;
        }

        @Override
        public String toString() {
            return String.valueOf(value);
        }

        @JsonCreator
        public static TypeEnum fromValue(String value) {
            for (TypeEnum b : TypeEnum.values()) {
                if (b.value.equals(value)) {
                    return b;
                }
            }
            return UNKNOWN_DEFAULT_OPEN_API;
        }
    }

    public static final String JSON_PROPERTY_TYPE = "type";
    private TypeEnum type;

    public static final String JSON_PROPERTY_DISTANCE_FROM_LATEST_MAJOR = "distanceFromLatestMajor";
    private Integer distanceFromLatestMajor;

    public static final String JSON_PROPERTY_LATEST_SECURITY_PATCH = "latestSecurityPatch";
    private Boolean latestSecurityPatch;

    public OSVersionConstraintDynamicVersionRequirement() {
    }

    public OSVersionConstraintDynamicVersionRequirement type(TypeEnum type) {

        this.type = type;
        return this;
    }

    /**
     * Indicates the type of the dynamic Windows version requirement
     *
     * @return type
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Indicates the type of the dynamic Windows version requirement")
    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public TypeEnum getType() {
        return type;
    }

    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setType(TypeEnum type) {
        this.type = type;
    }

    public OSVersionConstraintDynamicVersionRequirement distanceFromLatestMajor(Integer distanceFromLatestMajor) {

        this.distanceFromLatestMajor = distanceFromLatestMajor;
        return this;
    }

    /**
     * Indicates the distance from the latest Windows major version minimum: 0 maximum: 1
     *
     * @return distanceFromLatestMajor
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Indicates the distance from the latest Windows major version")
    @JsonProperty(JSON_PROPERTY_DISTANCE_FROM_LATEST_MAJOR)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Integer getDistanceFromLatestMajor() {
        return distanceFromLatestMajor;
    }

    @JsonProperty(JSON_PROPERTY_DISTANCE_FROM_LATEST_MAJOR)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDistanceFromLatestMajor(Integer distanceFromLatestMajor) {
        this.distanceFromLatestMajor = distanceFromLatestMajor;
    }

    public OSVersionConstraintDynamicVersionRequirement latestSecurityPatch(Boolean latestSecurityPatch) {

        this.latestSecurityPatch = latestSecurityPatch;
        return this;
    }

    /**
     * Indicates whether the policy requires Windows devices to be on the latest security patch
     *
     * @return latestSecurityPatch
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Indicates whether the policy requires Windows devices to be on the latest security patch")
    @JsonProperty(JSON_PROPERTY_LATEST_SECURITY_PATCH)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getLatestSecurityPatch() {
        return latestSecurityPatch;
    }

    @JsonProperty(JSON_PROPERTY_LATEST_SECURITY_PATCH)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLatestSecurityPatch(Boolean latestSecurityPatch) {
        this.latestSecurityPatch = latestSecurityPatch;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        OSVersionConstraintDynamicVersionRequirement osVersionConstraintDynamicVersionRequirement = (OSVersionConstraintDynamicVersionRequirement) o;
        return Objects.equals(this.type, osVersionConstraintDynamicVersionRequirement.type)
                && Objects.equals(this.distanceFromLatestMajor,
                        osVersionConstraintDynamicVersionRequirement.distanceFromLatestMajor)
                && Objects.equals(this.latestSecurityPatch,
                        osVersionConstraintDynamicVersionRequirement.latestSecurityPatch);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(type, distanceFromLatestMajor, latestSecurityPatch);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class OSVersionConstraintDynamicVersionRequirement {\n");
        sb.append("    type: ").append(toIndentedString(type)).append("\n");
        sb.append("    distanceFromLatestMajor: ").append(toIndentedString(distanceFromLatestMajor)).append("\n");
        sb.append("    latestSecurityPatch: ").append(toIndentedString(latestSecurityPatch)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/OSVersionConstraintDynamicVersionRequirement.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Contains the necessary properties for a dynamic Windows version requirement
 */
@ApiModel(description = "Contains the necessary properties for a dynamic Windows version requirement")
@JsonPropertyOrder({ OSVersionConstraintDynamicVersionRequirement.JSON_PROPERTY_TYPE,
        OSVersionConstraintDynamicVersionRequirement.JSON_PROPERTY_DISTANCE_FROM_LATEST_MAJOR,
        OSVersionConstraintDynamicVersionRequirement.JSON_PROPERTY_LATEST_SECURITY_PATCH })
@JsonTypeName("OSVersionConstraint_dynamicVersionRequirement")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class OSVersionConstraintDynamicVersionRequirement implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * Indicates the type of the dynamic Windows version requirement
     */
    public enum TypeEnum {
        MINIMUM("MINIMUM"),

        EXACT("EXACT"),

        EXACT_ANY_SUPPORTED("EXACT_ANY_SUPPORTED"),

        NOT_ALLOWED("NOT_ALLOWED"),

        UNKNOWN_DEFAULT_OPEN_API("unknown_default_open_api");

        private String value;

        TypeEnum(String value) {
            this.value = value;
        }

        @JsonValue
        public String getValue() {
            return value;
        }

        @Override
        public String toString() {
            return String.valueOf(value);
        }

        @JsonCreator
        public static TypeEnum fromValue(String value) {
            for (TypeEnum b : TypeEnum.values()) {
                if (b.value.equals(value)) {
                    return b;
                }
            }
            return UNKNOWN_DEFAULT_OPEN_API;
        }
    }

    public static final String JSON_PROPERTY_TYPE = "type";
    private TypeEnum type;

    public static final String JSON_PROPERTY_DISTANCE_FROM_LATEST_MAJOR = "distanceFromLatestMajor";
    private Integer distanceFromLatestMajor;

    public static final String JSON_PROPERTY_LATEST_SECURITY_PATCH = "latestSecurityPatch";
    private Boolean latestSecurityPatch;

    public OSVersionConstraintDynamicVersionRequirement() {
    }

    public OSVersionConstraintDynamicVersionRequirement type(TypeEnum type) {

        this.type = type;
        return this;
    }

    /**
     * Indicates the type of the dynamic Windows version requirement
     *
     * @return type
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Indicates the type of the dynamic Windows version requirement")
    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public TypeEnum getType() {
        return type;
    }

    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setType(TypeEnum type) {
        this.type = type;
    }

    public OSVersionConstraintDynamicVersionRequirement distanceFromLatestMajor(Integer distanceFromLatestMajor) {

        this.distanceFromLatestMajor = distanceFromLatestMajor;
        return this;
    }

    /**
     * Indicates the distance from the latest Windows major version minimum: 0 maximum: 1
     *
     * @return distanceFromLatestMajor
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Indicates the distance from the latest Windows major version")
    @JsonProperty(JSON_PROPERTY_DISTANCE_FROM_LATEST_MAJOR)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Integer getDistanceFromLatestMajor() {
        return distanceFromLatestMajor;
    }

    @JsonProperty(JSON_PROPERTY_DISTANCE_FROM_LATEST_MAJOR)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDistanceFromLatestMajor(Integer distanceFromLatestMajor) {
        this.distanceFromLatestMajor = distanceFromLatestMajor;
    }

    public OSVersionConstraintDynamicVersionRequirement latestSecurityPatch(Boolean latestSecurityPatch) {

        this.latestSecurityPatch = latestSecurityPatch;
        return this;
    }

    /**
     * Indicates whether the policy requires Windows devices to be on the latest security patch
     *
     * @return latestSecurityPatch
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Indicates whether the policy requires Windows devices to be on the latest security patch")
    @JsonProperty(JSON_PROPERTY_LATEST_SECURITY_PATCH)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getLatestSecurityPatch() {
        return latestSecurityPatch;
    }

    @JsonProperty(JSON_PROPERTY_LATEST_SECURITY_PATCH)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLatestSecurityPatch(Boolean latestSecurityPatch) {
        this.latestSecurityPatch = latestSecurityPatch;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        OSVersionConstraintDynamicVersionRequirement osVersionConstraintDynamicVersionRequirement = (OSVersionConstraintDynamicVersionRequirement) o;
        return Objects.equals(this.type, osVersionConstraintDynamicVersionRequirement.type)
                && Objects.equals(this.distanceFromLatestMajor,
                        osVersionConstraintDynamicVersionRequirement.distanceFromLatestMajor)
                && Objects.equals(this.latestSecurityPatch,
                        osVersionConstraintDynamicVersionRequirement.latestSecurityPatch);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(type, distanceFromLatestMajor, latestSecurityPatch);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class OSVersionConstraintDynamicVersionRequirement {\n");
        sb.append("    type: ").append(toIndentedString(type)).append("\n");
        sb.append("    distanceFromLatestMajor: ").append(toIndentedString(distanceFromLatestMajor)).append("\n");
        sb.append("    latestSecurityPatch: ").append(toIndentedString(latestSecurityPatch)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
